package guinand.mobapp.guidynamique;

import android.graphics.Color;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.GridLayout;
import android.widget.LinearLayout;
import android.widget.TextView;

import java.util.ArrayList;
import java.util.Random;

/**
 * Classe de démonstration pour la création d'une interface graphique dynamique
 * avec gestion du cycle de vie de l'activity.
 */
public class Home extends AppCompatActivity {

    Random alea;
    GridLayout gl;
    int nbTextView;
    ArrayList<TextView> tvs;
    ArrayList<Integer> tvCouleurs;
    ArrayList<Integer> tvPositions;
    ArrayList<String> tvTextes;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_home);
        initialisation();
    }

    /**
     * initialisation de la variable aléatoire, récupération de la référence
     * au GridLayout au sein duquel vont être ajoutées les TextView
     * et initialisation des ArrayList.
     */
    private void initialisation() {
        // initialisation de ma variable aléatoire
        alea = new Random(System.currentTimeMillis());
        // récupération de la référence au GridLayout pour
        // pouvoir ajouter les TextView
        gl = findViewById(R.id.gridlayout);
        tvs = new ArrayList<>();
        tvCouleurs = new ArrayList<>();
        tvPositions = new ArrayList<>();
        tvTextes = new ArrayList<>();
    }

    /**
     * méthode d'ajout des TextView au GridLayout
     * si le nombre actuel de TextView est de 9, on en supprime
     * aléatoirement entre 1 et 9 puis on en ajoute un nouveau.
     * Pour ajouter un TextView, on commence par choisir
     * aléatoirement une couleur et puis on lui assigne comme
     * texte un numéro qui correspond au nombre de TextView qui
     * ont été créés jusqu'à présent.
     * @param v
     */
    public void ajouter(View v) {
        if(tvs.size() >= 9) {
            int nbSuppressions = alea.nextInt(tvs.size());
            for(int s=0;s<nbSuppressions;s++) {
                int position = alea.nextInt(tvs.size());
                TextView delTv = tvs.remove(position);
                tvCouleurs.remove(position);
                tvTextes.remove(position);
                gl.removeView(delTv);
            }
        }
        TextView newTv = new TextView(this);
        int newCouleur = Color.rgb(alea.nextInt(255),alea.nextInt(255),alea.nextInt(255));
        tvCouleurs.add(newCouleur);
        newTv.setBackgroundColor(newCouleur);
        String newTexte = new String("textview : "+nbTextView);
        tvTextes.add(newTexte);
        newTv.setText(newTexte);
        tvs.add(newTv);
        gl.addView(newTv);
        nbTextView++;
    }

    // ================= gestion du cycle de vie ================

    @Override
    protected void onStart() {
        super.onStart();
    }

    @Override
    protected void onRestart() {
        super.onRestart();
    }

    /**
     * Ce qui doit être restauré : le nombre de TV déjà créés, la position,
     * le numéro et la couleur de chaque TextView qui se trouvaient dans le GridLayout
     * avant la destruction/reconstruction de l'application.
     * @param mesDonnees
     */
    @Override
    protected void onRestoreInstanceState(Bundle mesDonnees) {
        super.onRestoreInstanceState(mesDonnees);
        nbTextView = mesDonnees.getInt("nb");
        tvCouleurs = mesDonnees.getIntegerArrayList("couleurs");
        tvTextes = mesDonnees.getStringArrayList("textes");
        for(int tv = 0; tv<tvCouleurs.size();tv++) {
            TextView newTv = new TextView(this);
            newTv.setBackgroundColor(tvCouleurs.get(tv));
            newTv.setText(tvTextes.get(tv));
            tvs.add(newTv);
            gl.addView(newTv);
        }
    }

    @Override
    protected void onResume() {
        super.onResume();
    }

    @Override
    protected void onPause() {
        super.onPause();
    }

    /**
     * Ce qui doit être sauvegardé : le nombre de TV déjà créés, la position,
     * le numéro et la couleur de chaque TextView actuellement dans le GridLayout
     * ce qui peut être fait, par exemple, au moyen de trois ArrayList.
     * @param mesDonnees
     */
    @Override
    protected void onSaveInstanceState(Bundle mesDonnees) {
        mesDonnees.putInt("nb",nbTextView);
        mesDonnees.putStringArrayList("textes",tvTextes);
        mesDonnees.putIntegerArrayList("couleurs",tvCouleurs);
        super.onSaveInstanceState(mesDonnees);
    }

    @Override
    protected void onStop() {
        super.onStop();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
    }
}
